@@ -1,19 +1,21 @@
 function _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator(p) {
 }
-function _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps(p) {
-}
 function _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps(p) {
+}
+function _aws_cdk_aws_iot_actions_SqsQueueActionProps(p) {
+}
 function _aws_cdk_aws_iot_actions_CommonActionProps(p) {
 }
+function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps(p) {
+}
 function _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction(p) {
 }
 function _aws_cdk_aws_iot_actions_LambdaFunctionAction(p) {
 }
 function _aws_cdk_aws_iot_actions_CloudWatchLogsAction(p) {
 }
-function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
-}
 function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
     if (p == null)
         return;
@@ -22,8 +24,14 @@ function _aws_cdk_aws_iot_actions_FirehoseStreamActionProps(p) {
         _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator(p.recordSeparator);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction(p) {
+}
+function _aws_cdk_aws_iot_actions_FirehoseStreamAction(p) {
+}
 function _aws_cdk_aws_iot_actions_S3PutObjectAction(p) {
 }
+function _aws_cdk_aws_iot_actions_SqsQueueAction(p) {
+}
 function _aws_cdk_aws_iot_actions_S3PutObjectActionProps(p) {
 }
 function print(name, deprecationMessage) {
@@ -41,5 +49,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
+module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseStreamRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_SqsQueueActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehoseStreamActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction, _aws_cdk_aws_iot_actions_FirehoseStreamAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_SqsQueueAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
 module.exports.DeprecationError = DeprecationError;
